@@ -78,6 +78,7 @@ class AnuvaadHiTokenizer(object):
         text = self.serialize_table_points(text)
         text = self.serialize_url(text)
         text = self.serialize_dots(text)
+        text = self.serialize_consecutive_dots(text)
         text = self.serialize_brackets(text)
         text = self.serialize_dot_with_number(text)
         text = self.serialize_dot_with_number_beginning(text)
@@ -94,6 +95,7 @@ class AnuvaadHiTokenizer(object):
             se = self.deserialize_pattern(se)
             se = self.deserialize_url(se)
             se = self.deserialize_dots(se)
+            se = self.deserialize_consecutive_dots(se)
             se = self.deserialize_decimal(se)
             se = self.deserialize_brackets(se)
             se = self.deserialize_dot_with_number(se)
@@ -342,6 +344,16 @@ class AnuvaadHiTokenizer(object):
         text = pattern.sub('......', text)
         return text
 
+    def serialize_consecutive_dots(self, text):
+        pattern = re.compile(r'([.\s]{3,})')
+        text = pattern.sub('YY__YY', text)
+        return text
+
+    def deserialize_consecutive_dots(self, text):
+        pattern = re.compile(re.escape('YY__YY'), re.IGNORECASE)
+        text = pattern.sub('........', text)
+        return text
+
     def serialize_pattern(self, text):
         patterns = re.findall(r'([\u0900-\u097F][.]){2,}',text)
         index = 0
