@@ -71,6 +71,7 @@ class AnuvaadKnTokenizer(object):
         text = self.serialize_url(text)
         text = self.serialize_pattern(text)
         text = self.serialize_dots(text)
+        text = self.serialize_consecutive_dots(text)
         test = self.serialize_end(text)
         text = self.serialize_brackets(text)
         text = self.serialize_dot_with_number(text)
@@ -87,6 +88,7 @@ class AnuvaadKnTokenizer(object):
             se = self.deserialize_pattern(se)
             se = self.deserialize_url(se)
             se = self.deserialize_dots(se)
+            se = self.deserialize_consecutive_dots(se)
             se = self.deserialize_end(se)
             se = self.deserialize_decimal(se)
             se = self.deserialize_brackets(se)
@@ -328,6 +330,16 @@ class AnuvaadKnTokenizer(object):
         text = pattern.sub('......', text)
         return text
 
+    def serialize_consecutive_dots(self, text):
+        pattern = re.compile(r'([.\s]{3,})')
+        text = pattern.sub('YY__YY', text)
+        return text
+
+    def deserialize_consecutive_dots(self, text):
+        pattern = re.compile(re.escape('YY__YY'), re.IGNORECASE)
+        text = pattern.sub('........', text)
+        return text
+
     def serialize_pattern(self, text):
         patterns = re.findall(r'([\u0C80-\u0CF2][.]){2,}',text)
         index = 0
