@@ -1,7 +1,11 @@
-__version__ = '0.0.1'
+__version__ = '0.0.3'
 from Anuvaad_Tokenizer.AnuvaadEnTokenizer import AnuvaadEnTokenizer
 from Anuvaad_Tokenizer.AnuvaadEnTokenizer import SentenceEndLangVars
 from Anuvaad_Tokenizer.AnuvaadKnTokenizer import AnuvaadKnTokenizer
 from Anuvaad_Tokenizer.AnuvaadKnTokenizer import SentenceEndLangVars
 from Anuvaad_Tokenizer.AnuvaadHiTokenizer import AnuvaadHiTokenizer
 from Anuvaad_Tokenizer.AnuvaadHiTokenizer import SentenceEndLangVars
+from Anuvaad_Tokenizer.AnuvaadTeTokenizer import AnuvaadTeTokenizer
+from Anuvaad_Tokenizer.AnuvaadTeTokenizer import SentenceEndLangVars
+from Anuvaad_Tokenizer.AnuvaadTaTokenizer import AnuvaadTaTokenizer
+from Anuvaad_Tokenizer.AnuvaadTaTokenizer import SentenceEndLangVars
